Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(236)

Unified Diff: net/http/http_network_transaction.cc

Issue 2130493002: Implement THROTTLED priority semantics. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@NetworkStreamThrottler
Patch Set: All non-merge updates since stamps. Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/http/http_network_transaction.cc
diff --git a/net/http/http_network_transaction.cc b/net/http/http_network_transaction.cc
index 3d39fd6e139736aec6f28279d497fe901c4a2468..c31f04ba6e4db4a25931ddbd51eba5d7ddafbefb 100644
--- a/net/http/http_network_transaction.cc
+++ b/net/http/http_network_transaction.cc
@@ -593,9 +593,10 @@ void HttpNetworkTransaction::GetConnectionAttempts(
*out = connection_attempts_;
}
-void HttpNetworkTransaction::OnThrottleStateChanged() {
+void HttpNetworkTransaction::OnThrottleUnblocked(
+ NetworkThrottleManager::Throttle* throttle) {
// TODO(rdsmith): This DCHECK is dependent on the only transition
// being from throttled->unthrottled. That is true right now, but may not
// be so in the future.
DCHECK_EQ(STATE_THROTTLE_COMPLETE, next_state_);
@@ -798,11 +799,12 @@ int HttpNetworkTransaction::DoLoop(int result) {
}
int HttpNetworkTransaction::DoThrottle() {
+ DCHECK(!throttle_);
throttle_ = session_->throttler()->CreateThrottle(
this, priority_, (request_->load_flags & LOAD_IGNORE_LIMITS) != 0);
next_state_ = STATE_THROTTLE_COMPLETE;
- if (throttle_->IsThrottled()) {
+ if (throttle_->IsBlocked()) {
net_log_.BeginEvent(NetLogEventType::HTTP_TRANSACTION_THROTTLED);
return ERR_IO_PENDING;
}
@@ -812,7 +814,7 @@ int HttpNetworkTransaction::DoThrottle() {
int HttpNetworkTransaction::DoThrottleComplete() {
DCHECK(throttle_);
- DCHECK(!throttle_->IsThrottled());
+ DCHECK(!throttle_->IsBlocked());
next_state_ = STATE_NOTIFY_BEFORE_CREATE_STREAM;

Powered by Google App Engine
@@ -593,9 +593,10 @@ void HttpNetworkTransaction::GetConnectionAttempts(
// TODO(rdsmith): This DCHECK is dependent on the only transition
- // being from throttled->unthrottled. That is true right now, but may not
+ // being from blocked->unblocked. That is true right now, but may not
// be so in the future.
DCHECK_EQ(STATE_THROTTLE_COMPLETE, next_state_);
This is Rietveld 408576698